@@ -517,9 +517,7 @@ void * assemble_KMA_threaded(void *arg) {
 										for(j = 0; j < 6; ++j) {
 											myBias += assembly[pos].counts[j];
 										}
-										if(myBias > 0) { /* here */ /* not here */ /* why subtract one */ /* and check prior to insertion, for which -- is appropiate */
-											--myBias;
-										}
+										
 										/* find position of insertion */
 										gaps = pos;
 										if(pos != 0) {
@@ -1320,7 +1318,7 @@ void alnToMat(AssemInfo *matrix, Assem *aligned_assem, Aln *aligned, AlnScore al
 	
 	static volatile int Lock = 0;
 	volatile int *excludeMatrix = &Lock;
-	int i, pos, aln_len, start, read_score, myBias, gaps;
+	int i, pos, aln_len, start, read_score, myBias, tmp, gaps;
 	short unsigned *counts;
 	Assembly *assembly;
 	
@@ -1339,8 +1337,23 @@ void alnToMat(AssemInfo *matrix, Assem *aligned_assem, Aln *aligned, AlnScore al
 	}
 	++aligned_assem->readCountAln;
 	
-	/* diff */
+	/* trim trailing gaps */
+	i = aln_len - 1;
+	while(i && (aligned->t[i] == 5 || aligned->q[i] == 5)) {
+		--i;
+	}
+	aln_len = i + 1;
+	
+	/* trim leading gaps */
 	i = 0;
+	while(i < aln_len && (aligned->t[i] == 5 || aligned->q[i] == 5)) {
+		if(aligned->q[i] == 5) {
+			++start;
+		}
+		++i;
+	}
+	
+	/* diff */
 	pos = start;
 	assembly = matrix->assmb;
 	while(i < aln_len) {
@@ -1356,20 +1369,29 @@ void alnToMat(AssemInfo *matrix, Assem *aligned_assem, Aln *aligned, AlnScore al
 				gaps = pos;
 				pos = pos ? (pos - 1) : (t_len - 1);
 				
-				/* find position of insertion, it it already exists */
+				/* find position of insertion, if it already exists */
 				while(assembly[pos].next != gaps) {
 					pos = assembly[pos].next;
 				}
 				
 				/* get number of bases not supporting the insertion */
 				counts = assembly[pos].counts;
-				myBias = counts[0] + counts[1] + counts[2] + counts[3] + counts[4] + counts[5] - 1;
+				myBias = *counts;
+				myBias += *++counts;
+				myBias += *++counts;
+				myBias += *++counts;
+				myBias += *++counts;
+				myBias += *++counts;
 				
 				/* get minimum of bases sorrounding new insertion */
 				counts = assembly[gaps].counts;
-				if((counts[0] + counts[1] + counts[2] + counts[3] + counts[4] + counts[5]) < myBias) {
-					myBias = counts[0] + counts[1] + counts[2] + counts[3] + counts[4] + counts[5];
-				}
+				tmp = *counts;
+				tmp += *++counts;
+				tmp += *++counts;
+				tmp += *++counts;
+				tmp += *++counts;
+				tmp += *++counts;
+				myBias = (tmp < myBias) ? tmp : (myBias - 1);
 				if(USHRT_MAX < myBias) {
 					myBias = USHRT_MAX;
 				}
@@ -1443,15 +1465,33 @@ void alnToMatDense(AssemInfo *matrix, Assem *aligned_assem, Aln *aligned, AlnSco
 	}
 	++aligned_assem->readCountAln;
 	
+	/* trim trailing gaps */
+	i = aln_len - 1;
+	while(i < aln_len && (aligned->t[i] == 5 || aligned->q[i] == 5)) {
+		--i;
+	}
+	aln_len = i + 1;
+	
+	/* trim leading gaps */
+	i = 0;
+	while(i && (aligned->t[i] == 5 || aligned->q[i] == 5)) {
+		if(aligned->q[i] == 5) {
+			++start;
+		}
+		++i;
+	}
+	
 	/* diff */
+	pos = start;
 	assembly = matrix->assmb;
-	for(i = 0, pos = start; i < aln_len; ++i) {
+	while(i < aln_len) {
 		if(aligned->t[i] != 5) {
 			if(!++assembly[pos].counts[aligned->q[i]]) {
 				assembly[pos].counts[aligned->q[i]] = USHRT_MAX;	
 			}
 			pos = assembly[pos].next;
 		}
+		++i;
 	}
 	unlock(excludeMatrix);
 }
