@@ -21,6 +21,7 @@
 #include "compdna.h"
 #include "pherror.h"
 #include "runinput.h"
+#include "qc.h"
 #include "qseqs.h"
 #include "trim.h"
 
@@ -132,7 +133,7 @@ static int helpMessage(FILE *out) {
 	fprintf(out, "# %16s\t%-32s\t%s\n", "-ipe", "Paired input files", "");
 	fprintf(out, "# %16s\t%-32s\t%s\n", "-int", "Inerleaved input file(s)", "");
 	fprintf(out, "# %16s\t%-32s\t%s\n", "-o", "Output file", "STDOUT");
-	fprintf(out, "# %16s\t%-32s\t%s\n", "-oi", "Interleaved output file", "STDOUT");
+	fprintf(out, "# %16s\t%-32s\t%s\n", "-qc", "Report QC, repeat for verbose", "");
 	fprintf(out, "# %16s\t%-32s\t%s\n", "-ml", "Minimum length", "16");
 	fprintf(out, "# %16s\t%-32s\t%s\n", "-xl", "Maximum length", "2147483647");
 	fprintf(out, "# %16s\t%-32s\t%s\n", "-mp", "Minimum phred", "20");
@@ -147,29 +148,45 @@ static int helpMessage(FILE *out) {
 
 int trim_main(int argc, char *argv[]) {
 	
-	static const double prob[128] = {
-		1.0000000000000000, 0.7943282347242815, 0.6309573444801932, 0.5011872336272722, 0.3981071705534972, 0.3162277660168379, 0.2511886431509580, 0.1995262314968880,
-		0.1584893192461113, 0.1258925411794167, 0.1000000000000000, 0.0794328234724281, 0.0630957344480193, 0.0501187233627272, 0.0398107170553497, 0.0316227766016838,
-		0.0251188643150958, 0.0199526231496888, 0.0158489319246111, 0.0125892541179417, 0.0100000000000000, 0.0079432823472428, 0.0063095734448019, 0.0050118723362727,
-		0.0039810717055350, 0.0031622776601684, 0.0025118864315096, 0.0019952623149689, 0.0015848931924611, 0.0012589254117942, 0.0010000000000000, 0.0007943282347243,
-		0.0006309573444802, 0.0005011872336273, 0.0003981071705535, 0.0003162277660168, 0.0002511886431510, 0.0001995262314969, 0.0001584893192461, 0.0001258925411794,
-		0.0001000000000000, 0.0000794328234724, 0.0000630957344480, 0.0000501187233627, 0.0000398107170553, 0.0000316227766017, 0.0000251188643151, 0.0000199526231497,
-		0.0000158489319246, 0.0000125892541179, 0.0000100000000000, 0.0000079432823472, 0.0000063095734448, 0.0000050118723363, 0.0000039810717055, 0.0000031622776602,
-		0.0000025118864315, 0.0000019952623150, 0.0000015848931925, 0.0000012589254118, 0.0000010000000000, 0.0000007943282347, 0.0000006309573445, 0.0000005011872336,
-		0.0000003981071706, 0.0000003162277660, 0.0000002511886432, 0.0000001995262315, 0.0000001584893192, 0.0000001258925412, 0.0000001000000000, 0.0000000794328235,
-		0.0000000630957344, 0.0000000501187234, 0.0000000398107171, 0.0000000316227766, 0.0000000251188643, 0.0000000199526231, 0.0000000158489319, 0.0000000125892541,
-		0.0000000100000000, 0.0000000079432823, 0.0000000063095734, 0.0000000050118723, 0.0000000039810717, 0.0000000031622777, 0.0000000025118864, 0.0000000019952623,
-		0.0000000015848932, 0.0000000012589254, 0.0000000010000000, 0.0000000007943282, 0.0000000006309573, 0.0000000005011872, 0.0000000003981072, 0.0000000003162278,
-		0.0000000002511886, 0.0000000001995262, 0.0000000001584893, 0.0000000001258925, 0.0000000001000000, 0.0000000000794328, 0.0000000000630957, 0.0000000000501187,
-		0.0000000000398107, 0.0000000000316228, 0.0000000000251189, 0.0000000000199526, 0.0000000000158489, 0.0000000000125893, 0.0000000000100000, 0.0000000000079433,
-		0.0000000000063096, 0.0000000000050119, 0.0000000000039811, 0.0000000000031623, 0.0000000000025119, 0.0000000000019953, 0.0000000000015849, 0.0000000000012589,
-		0.0000000000010000, 0.0000000000007943, 0.0000000000006310, 0.0000000000005012, 0.0000000000003981, 0.0000000000003162, 0.0000000000002512, 0.0000000000001995};
+	static const double prob[256] = {1.00000000000000000000000000000000, 0.79432823472428149003121689020190, 0.63095734448019324958067954867147, 0.50118723362727224390766878059367, 0.39810717055349720272516833574628, 0.31622776601683794117647607890831, 0.25118864315095795758381314044527, 0.19952623149688791803768594945723,
+		0.15848931924611134314240246112604, 0.12589254117941672816982645599637, 0.10000000000000000555111512312578, 0.07943282347242813790089144276862, 0.06309573444801930275360746236402, 0.05011872336272722022743053571503, 0.03981071705534971333362292966740, 0.03162277660168379134209004632794,
+		0.02511886431509579437060253326308, 0.01995262314968878833432164299211, 0.01584893192461113431424024611260, 0.01258925411794166795975691286458, 0.01000000000000000020816681711722, 0.00794328234724281379008914427686, 0.00630957344480193027536074623640, 0.00501187233627271942065783960629,
+		0.00398107170553496907822177419689, 0.00316227766016837939441752602932, 0.00251188643150957943706025332631, 0.00199526231496887892016833809805, 0.00158489319246111256406228662286, 0.00125892541179416618882247469458, 0.00100000000000000002081668171172, 0.00079432823472428131395678407856,
+		0.00063095734448019298416798772422, 0.00050118723362727198543387086005, 0.00039810717055349691866419914454, 0.00031622776601683793944175260293, 0.00025118864315095795454804705749, 0.00019952623149688787575380122252, 0.00015848931924611125640622866229, 0.00012589254117941660804022574460,
+		0.00010000000000000000479217360239, 0.00007943282347242805821203176508, 0.00006309573444801929299578790999, 0.00005011872336272725139824299467, 0.00003981071705534969457692534567, 0.00003162277660168379529942797590, 0.00002511886431509577106025582482, 0.00001995262314968878622012740665,
+		0.00001584893192461110734471120554, 0.00001258925411794166114283575336, 0.00001000000000000000081803053914, 0.00000794328234724280480476363980, 0.00000630957344480192963839196990, 0.00000501187233627271480602234296, 0.00000398107170553496911887935567, 0.00000316227766016837919112961869,
+		0.00000251188643150957719072887721, 0.00000199526231496887870671603539, 0.00000158489319246111090387771000, 0.00000125892541179416611428357534, 0.00000099999999999999995474811183, 0.00000079432823472428050165218766, 0.00000063095734448019296383919699, 0.00000050118723362727143825058693,
+		0.00000039810717055349692247584741, 0.00000031622776601683791911296187, 0.00000025118864315095769789706404, 0.00000019952623149688787067160354, 0.00000015848931924611109038777100, 0.00000012589254117941661672231345, 0.00000009999999999999999547481118, 0.00000007943282347242804751824081,
+		0.00000006309573444801929638391970, 0.00000005011872336272714382505869, 0.00000003981071705534968960060678, 0.00000003162277660168379191129619, 0.00000002511886431509577111319538, 0.00000001995262314968878640541586, 0.00000001584893192461110970052159, 0.00000001258925411794166101048686,
+		0.00000001000000000000000020922561, 0.00000000794328234724282195718082, 0.00000000630957344480191723068278, 0.00000000501187233627271471337811, 0.00000000398107170553496896006068, 0.00000000316227766016837952200186, 0.00000000251188643150958199168515, 0.00000000199526231496887450463852,
+		0.00000000158489319246111092869313, 0.00000000125892541179416626648481, 0.00000000100000000000000006228159, 0.00000000079432823472428217503857, 0.00000000063095734448019166102973, 0.00000000050118723362727142997878, 0.00000000039810717055349693736510, 0.00000000031622776601683795220019,
+		0.00000000025118864315095716519275, 0.00000000019952623149688748148313, 0.00000000015848931924611108769943, 0.00000000012589254117941661630872, 0.00000000010000000000000000364322, 0.00000000007943282347242789438643, 0.00000000006309573444801916610297, 0.00000000005011872336272714816776,
+		0.00000000003981071705534969502898, 0.00000000003162277660168379392755, 0.00000000002511886431509571975045, 0.00000000001995262314968874750208, 0.00000000001584893192461110747747, 0.00000000001258925411794166163087, 0.00000000000999999999999999939497, 0.00000000000794328234724278911553,
+		0.00000000000630957344480191677186, 0.00000000000501187233627271465522, 0.00000000000398107170553496950290, 0.00000000000316227766016837939275, 0.00000000000251188643150957181349, 0.00000000000199526231496887466943, 0.00000000000158489319246111099009, 0.00000000000125892541179416608231,
+		0.00000000000099999999999999997989, 0.00000000000079432823472427893175, 0.00000000000063095734448019171758, 0.00000000000050118723362727146552, 0.00000000000039810717055349692000, 0.00000000000031622776601683791908, 0.00000000000025118864315095719145, 0.00000000000019952623149688746694,
+		0.00000000000015848931924611108891, 0.00000000000012589254117941662843, 0.00000000000010000000000000000304, 0.00000000000007943282347242789317, 0.00000000000006309573444801916418, 0.00000000000005011872336272714403, 0.00000000000003981071705534969326, 0.00000000000003162277660168379569,
+		0.00000000000002511886431509571851, 0.00000000000001995262314968874606, 0.00000000000001584893192461110952, 0.00000000000001258925411794166158, 0.00000000000000999999999999999999, 0.00000000000000794328234724278869, 0.00000000000000630957344480191689, 0.00000000000000501187233627271456,
+		0.00000000000000398107170553496948, 0.00000000000000316227766016837941, 0.00000000000000251188643150957185, 0.00000000000000199526231496887469, 0.00000000000000158489319246111095, 0.00000000000000125892541179416628, 0.00000000000000100000000000000008, 0.00000000000000079432823472427887,
+		0.00000000000000063095734448019173, 0.00000000000000050118723362727146, 0.00000000000000039810717055349695, 0.00000000000000031622776601683793, 0.00000000000000025118864315095717, 0.00000000000000019952623149688748, 0.00000000000000015848931924611109, 0.00000000000000012589254117941662,
+		0.00000000000000010000000000000000, 0.00000000000000007943282347242789, 0.00000000000000006309573444801943, 0.00000000000000005011872336272714, 0.00000000000000003981071705534953, 0.00000000000000003162277660168380, 0.00000000000000002511886431509572, 0.00000000000000001995262314968883,
+		0.00000000000000001584893192461111, 0.00000000000000001258925411794161, 0.00000000000000001000000000000000, 0.00000000000000000794328234724279, 0.00000000000000000630957344480194, 0.00000000000000000501187233627271, 0.00000000000000000398107170553495, 0.00000000000000000316227766016838,
+		0.00000000000000000251188643150957, 0.00000000000000000199526231496888, 0.00000000000000000158489319246111, 0.00000000000000000125892541179416, 0.00000000000000000100000000000000, 0.00000000000000000079432823472428, 0.00000000000000000063095734448019, 0.00000000000000000050118723362727,
+		0.00000000000000000039810717055350, 0.00000000000000000031622776601684, 0.00000000000000000025118864315096, 0.00000000000000000019952623149689, 0.00000000000000000015848931924611, 0.00000000000000000012589254117942, 0.00000000000000000010000000000000, 0.00000000000000000007943282347243,
+		0.00000000000000000006309573444802, 0.00000000000000000005011872336273, 0.00000000000000000003981071705535, 0.00000000000000000003162277660168, 0.00000000000000000002511886431510, 0.00000000000000000001995262314969, 0.00000000000000000001584893192461, 0.00000000000000000001258925411794,
+		0.00000000000000000001000000000000, 0.00000000000000000000794328234724, 0.00000000000000000000630957344480, 0.00000000000000000000501187233627, 0.00000000000000000000398107170553, 0.00000000000000000000316227766017, 0.00000000000000000000251188643151, 0.00000000000000000000199526231497,
+		0.00000000000000000000158489319246, 0.00000000000000000000125892541179, 0.00000000000000000000100000000000, 0.00000000000000000000079432823472, 0.00000000000000000000063095734448, 0.00000000000000000000050118723363, 0.00000000000000000000039810717055, 0.00000000000000000000031622776602,
+		0.00000000000000000000025118864315, 0.00000000000000000000019952623150, 0.00000000000000000000015848931925, 0.00000000000000000000012589254118, 0.00000000000000000000010000000000, 0.00000000000000000000007943282347, 0.00000000000000000000006309573445, 0.00000000000000000000005011872336,
+		0.00000000000000000000003981071706, 0.00000000000000000000003162277660, 0.00000000000000000000002511886432, 0.00000000000000000000001995262315, 0.00000000000000000000001584893192, 0.00000000000000000000001258925412, 0.00000000000000000000001000000000, 0.00000000000000000000000794328235,
+		0.00000000000000000000000630957344, 0.00000000000000000000000501187234, 0.00000000000000000000000398107171, 0.00000000000000000000000316227766, 0.00000000000000000000000251188643, 0.00000000000000000000000199526231, 0.00000000000000000000000158489319, 0.00000000000000000000000125892541,
+		0.00000000000000000000000100000000, 0.00000000000000000000000079432823, 0.00000000000000000000000063095734, 0.00000000000000000000000050118723, 0.00000000000000000000000039810717, 0.00000000000000000000000031622777, 0.00000000000000000000000025118864, 0.00000000000000000000000019952623,
+		0.00000000000000000000000015848932, 0.00000000000000000000000012589254, 0.00000000000000000000000010000000, 0.00000000000000000000000007943282, 0.00000000000000000000000006309573, 0.00000000000000000000000005011872, 0.00000000000000000000000003981072, 0.00000000000000000000000003162278};
 	int i, args, fileCounter, fileCounter_PE, fileCounter_INT, fileCount;
 	int minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, maxlen;
 	long unsigned totFrags;
 	char **inputfiles, **inputfiles_PE, **inputfiles_INT;
-	char *to2Bit, *outputfilename, *outputfilename_int, *exeBasic;
-	FILE *out, *out_int;
+	char *to2Bit, *outputfilename, *exeBasic;
+	FILE *out, *out_int, *out_json;
+	QCstat *qcreport; 
 	
 	/* set defaults */
 	minPhred = 20;
@@ -186,9 +203,10 @@ int trim_main(int argc, char *argv[]) {
 	inputfiles_PE = 0;
 	inputfiles_INT = 0;
 	outputfilename = 0;
-	outputfilename_int = 0;
 	out = stdout;
 	out_int = stdout;
+	out_json = stderr;
+	qcreport = 0;
 	
 	/* PARSE COMMAND LINE OPTIONS */
 	args = 1;
@@ -260,11 +278,14 @@ int trim_main(int argc, char *argv[]) {
 				outputfilename = smalloc(strlen(argv[args]) + 64);
 				strcpy(outputfilename, argv[args]);
 			}
-		} else if(strcmp(argv[args], "-oi") == 0) {
-			++args;
-			if(args < argc) {
-				outputfilename_int = smalloc(strlen(argv[args]) + 64);
-				strcpy(outputfilename_int, argv[args]);
+		} else if(strcmp(argv[args], "-qc") == 0) {
+			if(qcreport) {
+				qcreport->verbose++;
+			} else {
+				qcreport = init_QCstat(0);
+				if(!qcreport) {
+					ERROR();
+				}
 			}
 		} else if(strcmp(argv[args], "-ml") == 0) {
 			++args;
@@ -341,13 +362,21 @@ int trim_main(int argc, char *argv[]) {
 	
 	/* set ptrs */
 	if(outputfilename) {
+		i = strlen(outputfilename);
+		sprintf(outputfilename + i, ".fq");
 		out = sfopen(outputfilename, "wb");
+		if(fileCounter_PE + fileCounter_INT) {
+			sprintf(outputfilename + i, "_int.fq");
+			out_int = sfopen(outputfilename, "wb");
+		}
+		if(qcreport) {
+			sprintf(outputfilename + i, ".json");
+			out_json = sfopen(outputfilename, "wb");
+		}
+		outputfilename[i] = 0;
 	}
 	printFsa_ptr = &printTrimFsa;
 	printFsa_ptr(0, 0, 0, 0, out);
-	if(outputfilename_int) {
-		out_int = sfopen(outputfilename_int, "wb");
-	}
 	printFsa_pair_ptr = &printTrimFsa_pair;
 	printFsa_pair_ptr(0, 0, 0, 0, 0, 0, 0, out_int);
 	
@@ -406,17 +435,35 @@ int trim_main(int argc, char *argv[]) {
 	
 	/* SE */
 	if(fileCounter > 0) {
-		totFrags += run_input(inputfiles, fileCounter, minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, maxlen, to2Bit, prob, out);
+		totFrags += run_input(inputfiles, fileCounter, minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, maxlen, to2Bit, prob, qcreport, out);
 	}
 	
 	/* PE */
 	if(fileCounter_PE > 0) {
-		totFrags += run_input_PE(inputfiles_PE, fileCounter_PE, minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, to2Bit, prob, out);
+		totFrags += run_input_PE(inputfiles_PE, fileCounter_PE, minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, maxlen, to2Bit, prob, qcreport, out);
 	}
 	
 	/* INT */
 	if(fileCounter_INT > 0) {
-		totFrags += run_input_INT(inputfiles_INT, fileCounter_INT, minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, to2Bit, prob, out);
+		totFrags += run_input_INT(inputfiles_INT, fileCounter_INT, minPhred, minmaskQ, minQ, fiveClip, threeClip, minlen, maxlen, to2Bit, prob, qcreport, out);
+	}
+	
+	/* print QC */
+	if(qcreport) {
+		print_QCstat(qcreport, minQ, minPhred, minmaskQ, minlen, maxlen, fiveClip, threeClip, out_json);
+		destroy_QCstat(qcreport);
+	}
+	
+	/* clean up */
+	free(outputfilename);
+	if(out != stdout) {
+		fclose(out);
+	}
+	if(out_int != stdout) {
+		fclose(out_int);
+	}
+	if(out_json != stderr) {
+		fclose(out_json);
 	}
 	
 	fprintf(stderr, "#\n# Total number of query fragment after trimming:\t%lu\n", totFrags);
